import setuptools

setuptools.setup(
	name='pygen-controlcharts',
	version='1.0',
	author='andrey140',
	author_email='andrexa33455@gmail.com',
	description='Will add',
	url='https://github.com/SpbskvA/math-stat.git',
	packages=['pygen-controlcharts'],
	include_package_data=True,
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)